summaryrefslogtreecommitdiff
path: root/round-robin.sh
diff options
context:
space:
mode:
Diffstat (limited to 'round-robin.sh')
-rw-r--r--round-robin.sh27
1 files changed, 15 insertions, 12 deletions
diff --git a/round-robin.sh b/round-robin.sh
index 82cfc1d0..ac1ff3b3 100644
--- a/round-robin.sh
+++ b/round-robin.sh
@@ -6,19 +6,22 @@
# PROJECT's git url
#rr[PROJECT_url]
-# PROJECT's git revision parsable by git rev-parse.
+# PROJECT's git branch or SHA1 revision parsable by git rev-parse.
+#rr[PROJECT_branch]
+
+# PROJECT's git SHA1 revision. These are mostly used in manifests.
#rr[PROJECT_rev]
# Baseline branch name for current configuration. These branches are
# present in all above git repos.
#rr[baseline_branch]="linaro-local/ci/CONFIGURATION"
# PROJECT that we are testing in this build. Use ${rr[current_rev]} for
# this project, and ${rr[baseline_branch]} for all other projects.
#rr[current_project]="$current_project"
-# Git revision of ${rr[current_project]} to test.
-#rr[current_rev]="$current_rev"
+# Git branch or SHA1 revision of ${rr[current_project]} to test.
+#rr[current_branch]="$current_branch"
# Run mode: bisect or non-bisect. In bisect mode we do a couple things
# slightly differently (e.g., don't touch repo in clone_repo() ).
@@ -84,21 +87,21 @@ clone_repo ()
local branch
# Select the branch to build.
# ${rr[current_rev]} specifies branch for ${rr[current_project]},
# and everything else uses baseline branch.
if [ x"$project" = x"${rr[current_project]}" ]; then
- if [ x"${rr[current_rev]}" = x"default" ]; then
- branch=${rr[${current_project}_rev]}
- elif [ x"${rr[current_rev]}" = x"baseline" ]; then
+ if [ x"${rr[current_branch]}" = x"default" ]; then
+ branch=${rr[${current_project}_branch]}
+ elif [ x"${rr[current_branch]}" = x"baseline" ]; then
branch="refs/remotes/baseline/${rr[baseline_branch]}"
else
- branch=${rr[current_rev]}
+ branch=${rr[current_branch]}
fi
else
branch="refs/remotes/baseline/${rr[baseline_branch]}"
fi
- branch="${rr[${project}_sha1]-$branch}"
+ branch="${rr[${project}_rev]-$branch}"
# Decide on whether to use read-only or read-write mode for
# refs/remotes/baseline. We use read-only wherever possible to allow
@@ -121,14 +124,14 @@ clone_repo ()
cur_rev=$(git -C $project rev-parse HEAD)
cat <<EOF | manifest_out
-rr[${project}_sha1]=$cur_rev
+rr[${project}_rev]=$cur_rev
EOF
if [ x"$project" = x"${rr[current_project]}" ]; then
local baseline_rev
baseline_rev=$(git_rev_parse_long $project ${rr[baseline_branch]} baseline)
# Prepare for failure. If build fails we will bisect sha1 for
- # ${rr[current_rev]} and sha1 for $baseline_rev.
+ # ${rr[current_branch]} and sha1 for ${rr[baseline_branch]}.
cat > ${rr[top_artifacts]}/trigger-bisect-on-failure <<EOF
current_project=${rr[current_project]}
baseline_rev=$baseline_rev
@@ -6,19 +6,22 @@
# present in all above git repos.
#rr[baseline_branch]="linaro-local/ci/CONFIGURATION"
-# PROJECT that we are testing in this build. Use ${rr[current_rev]} for
+# PROJECT that we are testing in this build. Use ${rr[current_branch]} for
# this project, and ${rr[baseline_branch]} for all other projects.
#rr[current_project]="$current_project"
@@ -84,21 +87,21 @@ clone_repo ()
local branch
# Select the branch to build.
- # ${rr[current_rev]} specifies branch for ${rr[current_project]},
+ # ${rr[current_branch]} specifies branch for ${rr[current_project]},
# and everything else uses baseline branch.
if [ x"$project" = x"${rr[current_project]}" ]; then